@@ -56,6 +56,9 @@ class Data(object):
     SDATA_CLASS = "!sdata_class"
     SDATA_PROJECT = "!sdata_project"
 
+    SDATA_ATTRIBUTES = [SDATA_VERSION, SDATA_NAME, SDATA_UUID, SDATA_CLASS, SDATA_PARENT, SDATA_PROJECT,
+                        SDATA_CTIME, SDATA_MTIME]
+
     def __init__(self, **kwargs):
         """create Data object
 
@@ -396,7 +399,8 @@ class Data(object):
     def _set_table(self, df):
         if isinstance(df, pd.DataFrame):
             self._table = df
-            self._table.index.name = "index"
+            if self._table.index.name is None:
+                self._table.index.name = "index"
 
     table = property(fget=_get_table, fset=_set_table, doc="table object(pandas.DataFrame)")
     df = table
@@ -592,7 +596,7 @@ class Data(object):
         return invalid_attrs
 
     def __str__(self):
-        return "(Data '%s':%s)" % (self.name, self.uuid)
+        return f"({self.__class__.__name__} '{self.name}':{self.uuid})"
 
     __repr__ = __str__
 
@@ -628,14 +632,14 @@ class Data(object):
 
     def add_data(self, data):
         """add data, if data.name is unique"""
-        if isinstance(data, Data):
+        if hasattr(data, "metadata"):
             names = [dat.name.lower() for uid, dat in self.group.items()]
             if data.name.lower() in names:
                 logger.error("{}: name '{}' aready exists".format(data.__class__.__name__, data.name))
                 return
             self.group[data.uuid] = data
         else:
-            logger.warning("ignore data %s (wrong type!)" % data)
+            logger.warning(f"ignore data {data}, {data.__class__.__name__} (wrong type!)")
 
     def get_data_by_uuid(self, uid):
         """get data by uuid"""
@@ -768,7 +772,8 @@ class Data(object):
 
             # data
             if self.table is not None:
-                self.table.index.name = "index"
+                if self._table.index.name is None:
+                    self._table.index.name = "index"
                 self.table.to_excel(writer, sheet_name='table')
                 adjust_col_width('table', self.table, writer, width=15)
             else:
@@ -796,14 +801,13 @@ class Data(object):
         try:
             if os.path.exists(filepath):
                 wb = openpyxl.load_workbook(filename=filepath)
-                # sheetname = u'Übergabedaten VWD für BFA'
                 sheetnames = wb.sheetnames
 
                 tt = cls(name=filepath)
 
                 # read df
                 if "table" in sheetnames:
-                    tt.table = pd.read_excel(filepath, sheet_name="table", index_col='index')
+                    tt.table = pd.read_excel(filepath, sheet_name="table", index_col=0)
                 else:
                     logger.info("no table data in '{}'".format(filepath))
                 dfm = pd.read_excel(filepath, sheet_name="metadata")
@@ -922,9 +926,11 @@ class Data(object):
         :param filepath:
         :return:
         """
+
         exportlines = []
         exportlines.append(self.metadata.to_csv_header(prefix="#;", sep=";", filepath=None))
-        exportlines.append(self.df.to_csv(sep=";"))
+        if self.df is not None:
+            exportlines.append(self.df.to_csv(sep=";"))
 
         exportstr = "".join(exportlines)
 
@@ -945,7 +951,7 @@ class Data(object):
         """
         data = cls()
         if filepath:
-            df = pd.read_csv(filepath, sep=";", comment="#")
+            df = pd.read_csv(filepath, sep=";", comment="#", index_col=0)
             sio = open(filepath, "r")
         elif s is not None:
             sio = StringIO(s)
@@ -953,12 +959,15 @@ class Data(object):
             sio.seek(0)
         else:
             logger.error("data.from_csv: no csv data available")
-            return
+            raise
 
+        attritute_list = []
         for line in sio:
             if line.startswith("#;"):
-                print(line)
-
+                line = line.rstrip("\n")
+                line = line.split(sep)
+                attritute_list.append(line[1:8])
+        data.metadata = Metadata.from_list(attritute_list)
         data.table = df
         return data
 
@@ -988,16 +997,32 @@ class Data(object):
             hdf.put('description'.format(self.uuid), self.description_to_df(), format='fixed', data_columns=True)
 
 
+    @classmethod
+    def metadata_from_hdf5(cls, filepath, **kwargs):
+        """import sdata.Data.Metadata from hdf5
+
+        :param filepath:
+        :return: sdata.Data
+        """
+        if not os.path.exists:
+            logger.error("hdf5 file '{}' not available".format(filepath))
+            return
+
+        with pd.HDFStore(filepath, mode="r+") as hdf:
+            metadata_path = "/metadata".format(uuid)
+            df_metadata = hdf.get(metadata_path)
+            metadata = Metadata.from_dataframe(df_metadata)
+            return metadata
+
     @classmethod
     def from_hdf5(cls, filepath, **kwargs):
         """import sdata.Data from hdf5
 
         :param filepath:
-        :param sep: separator (default=";")
         :return: sdata.Data
         """
         if not os.path.exists:
-            logger.error("hdf5 file '' notr available".format(filepath))
+            logger.error("hdf5 file '{}' not available".format(filepath))
             return
         
         with pd.HDFStore(filepath, mode="r+") as hdf:
@@ -1117,7 +1142,7 @@ class Data(object):
         except Exception as exp:
             raise
 
-    def copy(self):
+    def copy(self, **kwargs):
         """create a copy of the Data object
 
         .. code-block:: python
@@ -1140,6 +1165,12 @@ class Data(object):
         data.metadata.add(self.SDATA_PARENT, self.uuid)
         data.metadata.add(self.SDATA_UUID, self.gen_uuid())
         data.metadata.add(self.SDATA_MTIME, now_utc_str(), dtype="str")
+        if "uuid" in kwargs:
+            data.uuid = kwargs.get("uuid")
+        if "name" in kwargs:
+            data.name = kwargs.get("name")
+        logger.debug(f"make copy of {self.uuid} -> {data.uuid}")
+
         return data
 
     def gen_uuid(self):
