@@ -118,6 +118,8 @@ class Attribute(object):
                 self._value = None
             elif not value and self.dtype in ["int", "float"]:
                 self._value = np.nan
+            elif pd.isna(value) and self.dtype in ["int", "float"]:
+                self._value = np.nan
             elif dtype.__name__ == "bool" and value not in [1, "1", "true", "True"]:
                 self._value = False
             elif dtype.__name__ == "bool" and value in [1, "1", "true", "True"]:
@@ -304,10 +306,12 @@ class Metadata(object):
         if isinstance(name, Attribute):
             attr = name # name is the Attribute!
         else:
-            attr = self.get_attr(name) or Attribute(name, value, **kwargs)
+            attr = self.get_attr(prefix + name) or Attribute(name, value, **kwargs)
         for key in ["dtype", "unit", "description", "label", "required"]:
             if key in kwargs:
-                setattr(attr, key, kwargs.get(key))
+                if key in kwargs:
+                    # print("!!!", attr, key, kwargs.get(key))
+                    setattr(attr, key, kwargs.get(key))
         if value is not None:
             attr.value = value
         self._attributes[prefix + attr.name] = attr
@@ -381,9 +385,34 @@ class Metadata(object):
         metadata.update_from_dict(d)
         return metadata
 
-    def to_dataframe(self):
-        """create dataframe"""
-        d = self.to_dict()
+    def _to_dict(self, attributes):
+        """
+
+        :param attributes:
+        :return:
+        """
+        d = {}
+        for attr in attributes.values():
+            d[attr.name] = attr.to_dict()
+        return d
+
+    def get_sdict(self):
+        """get sdata attribute as dict"""
+        d = {}
+        for attr in self.sdata_attributes.values():
+            d[attr.name] = attr.value
+        return d
+
+    def get_udict(self):
+        """get user attribute as dict"""
+        d = {}
+        for attr in self.user_attributes.values():
+            d[attr.name] = attr.value
+        return d
+
+    def _to_dataframe(self, attributes):
+        """create dataframe from attributes"""
+        d = self._to_dict(attributes)
         if len(d) == 0:
             df = pd.DataFrame(columns=self.ATTRIBUTEKEYS)
         else:
@@ -391,15 +420,31 @@ class Metadata(object):
         df.index.name = "key"
         return df[self.ATTRIBUTEKEYS]
 
+    def to_dataframe(self):
+        """create dataframe"""
+        return self._to_dataframe(self.attributes)
+
     @property
     def df(self):
         """create dataframe"""
-        return self.to_dataframe()
+        return self._to_dataframe(self.attributes)
 
     @property
-    def user_df(self):
+    def udf(self):
         """create dataframe for user attributes"""
-        return self.to_dataframe()
+        return self._to_dataframe(self.user_attributes)
+
+    @property
+    def sdf(self):
+        """create dataframe for sdata attributes"""
+        return self._to_dataframe(self.sdata_attributes)
+
+    @property
+    def sdft(self):
+        """create transposed dataframe for sdata attributes"""
+        mt = self.sdf[["value"]].transpose(copy=True)
+        mt.index = [self.get("!sdata_uuid").value]
+        return mt
 
     @classmethod
     def from_dataframe(cls, df):
@@ -408,6 +453,11 @@ class Metadata(object):
         metadata = cls.from_dict(d)
         return metadata
 
+    def update_from_usermetadata(self, metadata):
+        """update user metadata from metadata"""
+        for attribute in metadata.user_attributes.values():
+            self.add(attribute)
+
     def to_csv(self, filepath=None, sep=",", header=False):
         """serialize to csv"""
         try:
@@ -484,7 +534,7 @@ class Metadata(object):
         """create metadata from a list of Attribute values
 
         [['force_x', 1.2, 'float', 'kN', 'force in x-direction'],
-         ['force_y', 3.1, 'float', 'N', 'force in y-direction']]
+         ['force_y', 3.1, 'float', 'N', 'force in y-direction', 'label', True]]
          """
         metadata = cls()
         for alist in mlist:
@@ -494,7 +544,7 @@ class Metadata(object):
                 alist.extend(["", "", "", ""])
                 #["name", "value", "dtype", "unit", "description"]
                 metadata.add(alist[0], alist[1], dtype=alist[2], unit=alist[3], description=alist[4],
-                             label=alist[5])
+                             label=alist[5], required=alist[6])
         return metadata
 
     def __repr__(self):
